# SBOM Discovery from Build Artifacts
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts#prerequisites)
  * [Configuration](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts#configuration)
  * [SBOM Naming Convention](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts#sbom-naming-convention)
  * [Branches](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts#branches)
  * [GitHub App Permissions](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts#github-app-permissions)
  * [Example](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts#example)


Set up automated discovery of SBOMs in your GitHub Enterprise Server instance and seamlessly send them to SAP LeanIX for further processing.
The GitHub Enterprise Server integration supports automatic detection and processing of Software Bill of Materials (SBOMs) generated within GitHub Actions workflows. The integration sends SBOMs to SAP LeanIX for further processing, accelerating the discovery of microservices and improving visibility.
By automating SBOM discovery and linking to SAP LeanIX, the integration eliminates manual efforts, speeding up microservices and tech stack discovery.
